Module strum

Module strum 

Re-exports of the strum traits implemented by LucideGlyph. Importing from here lets downstream callers iterate or look up icons without taking a direct strum dependency.

Traits

EnumProperty
EnumProperty is a trait that makes it possible to store additional information with enum variants. This trait is designed to be used with the macro of the same name in the strum_macros crate. Currently, the string, integer and bool literals are supported in attributes.
IntoEnumIterator
This trait designates that an Enum can be iterated over. It can be auto generated using the EnumIter derive macro.