Re-exports of the strum traits implemented
by LucideGlyph. Importing from here lets downstream callers iterate
or look up icons without taking a direct strum dependency.
Traits
- Enum
Property EnumPropertyis a trait that makes it possible to store additional information with enum variants. This trait is designed to be used with the macro of the same name in thestrum_macroscrate. Currently, the string, integer and bool literals are supported in attributes.- Into
Enum Iterator - This trait designates that an
Enumcan be iterated over. It can be auto generated using theEnumIterderive macro.